internal

package
v0.7.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package internal contains types for code generation. These types are exported for use by tygorgen but are not intended for direct use.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MethodMetadata

type MethodMetadata struct {
	Name       string
	HTTPMethod string
	Request    reflect.Type
	Response   reflect.Type
}

MethodMetadata holds runtime metadata for a registered service method.

type RouteMap

type RouteMap map[string]*MethodMetadata

RouteMap maps route names to their metadata.

Directories

Path Synopsis
Package testfixtures provides types used for testing the tygorgen package.
Package testfixtures provides types used for testing the tygorgen package.
Package tgrcontext provides the shared context key for tygor.
Package tgrcontext provides the shared context key for tygor.
Package tygortest provides testing helpers for HTTP handlers and tygor service handlers.
Package tygortest provides testing helpers for HTTP handlers and tygor service handlers.

Jump to